// uidstr.h
//
// This program is free software. See the file COPYING for details.
// Author: Mattias Engdegrd, 1997-1999

#ifndef UIDSTR_H
#define UIDSTR_H

#include <qintdict.h>
#include <qstring.h>

class Uidstr {
public:
    static QString userName(int uid);
    static QString groupName(int gid);

private:
    static QIntDict<char> udict;
    static QIntDict<char> gdict;
};

#endif	// UIDSTR_H
